@@ -1,6 +1,7 @@
 import os
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 import sys
+import time
 import shutil
 import argparse
 import logging
@@ -26,6 +27,7 @@ prediction_dir = os.path.join(WORKING_PATH,'src','tigerseg','result')
 
 def apply(input=None,output=prediction_dir,modelpath=os.getcwd(),only_CPU=False,permute=False):
 
+    start = time.time()
     model_file = os.path.join(modelpath,model_url.split('/')[-1])
     if not os.path.exists(model_file):
         logging.info(f'Downloading model files....')
@@ -34,9 +36,9 @@ def apply(input=None,output=prediction_dir,modelpath=os.getcwd(),only_CPU=False,
         logging.info(only_CPU)
         os.environ['CUDA_VISIBLE_DEVICES'] = '-1'
     if tf.test.gpu_device_name():
-        logging.info('Default GPU Device: {}'.format(tf.test.gpu_device_name()))
+        logging.info('GPU Device: {}'.format(tf.test.gpu_device_name()))
     else:
-        logging.info("Please install GPU version of TF")
+        logging.info("Now you are uainde CPU version of TF")
 
 
     config = dict()
@@ -66,10 +68,13 @@ def apply(input=None,output=prediction_dir,modelpath=os.getcwd(),only_CPU=False,
                             permute=False,
                             output_basename=output_name,
                             test=False)
-
+        logging.info(f'{output_name} is finished.')
         prediction_filename = os.path.join(os.path.join(output,output_name))
         ref = nib.load(data_file)
         pred = nib.load(prediction_filename)
         pred_resampled = resample_to_img(pred, ref, interpolation="nearest")
         nib.save(pred_resampled,prediction_filename)
-        logging.info(f'Save result to: {output}')
+
+    end = time.time()
+    logging.info(f'Save result to: {output}')
+    logging.info('Total cost was:%.2f secs' % (end - start))
